pyLBM.Scheme
============

.. currentmodule:: pyLBM

.. autoclass:: Scheme

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Scheme.compute_amplification_matrix
         Scheme.compute_amplification_matrix_relaxation
         Scheme.compute_consistency
         Scheme.create_moments_matrices
         Scheme.equilibrium
         Scheme.f2m
         Scheme.generate
         Scheme.is_L2_stable
         Scheme.is_monotonically_stable
         Scheme.m2f
         Scheme.onetimestep
         Scheme.relaxation
         Scheme.set_boundary_conditions
         Scheme.set_initialization
         Scheme.set_source_terms
         Scheme.source_term
         Scheme.transport
         Scheme.vp_amplification_matrix



   

